@@ -1,17 +1,14 @@
 # testing features, to be called by nosetests
 
-import logging
 import os
 import shutil
-import sys
 import tempfile
 import unittest
 
-from fiona import collection
+import fiona
 from fiona.collection import Collection
 from fiona.ogrext import featureRT
 
-#logging.basicConfig(stream=sys.stderr, level=logging.INFO)
 
 class PointRoundTripTest(unittest.TestCase):
     def setUp(self):
@@ -110,3 +107,27 @@ class PolygonRoundTripTest(unittest.TestCase):
         g = featureRT(f, self.c)
         self.assertEqual(g['properties']['title'], 'foo')
 
+
+class NullFieldTest(unittest.TestCase):
+    """See issue #460."""
+
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp()
+
+    def tearDown(self):
+        shutil.rmtree(self.tempdir)
+
+    def test_feature_null_field(self):
+        """Undefined int feature properties are None, not 0"""
+
+        meta = {"driver": "ESRI Shapefile", "schema": {"geometry": "Point", "properties": {"RETURN_P": "int"}}}
+        filename = os.path.join(self.tempdir, "test_null.shp")
+
+        with fiona.open(filename, "w", **meta) as dst:
+            g = {"coordinates": [1.0, 2.0], "type": "Point"}
+            feature = {"geometry": g, "properties": {"RETURN_P": None}}
+            dst.write(feature)
+
+        with fiona.open(filename, "r") as src:
+            feature = next(iter(src))
+            self.assertEqual(feature["properties"]["RETURN_P"], None)
